# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: draft/protos/ydb_dynamic_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v3.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='draft/protos/ydb_dynamic_config.proto',
  package='Ydb.DynamicConfig',
  syntax='proto3',
  serialized_options=b'\n\"tech.ydb.proto.draft.dynamicconfigZFgithub.com/ydb-platform/ydb-go-genproto/draft/protos/Ydb_DynamicConfig\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%draft/protos/ydb_dynamic_config.proto\x12\x11Ydb.DynamicConfig\x1a\x1aprotos/ydb_operation.proto\"2\n\x0e\x43onfigIdentity\x12\x0f\n\x07version\x18\x01 \x01(\x04\x12\x0f\n\x07\x63luster\x18\x02 \x01(\t\"\x8c\x01\n\x10SetConfigRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\t\x12\x0f\n\x07\x64ry_run\x18\x03 \x01(\x08\x12\x1c\n\x14\x61llow_unknown_fields\x18\x04 \x01(\x08\"A\n\x11SetConfigResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x90\x01\n\x14ReplaceConfigRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\t\x12\x0f\n\x07\x64ry_run\x18\x03 \x01(\x08\x12\x1c\n\x14\x61llow_unknown_fields\x18\x04 \x01(\x08\"E\n\x15ReplaceConfigResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x83\x01\n\x11\x44ropConfigRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x33\n\x08identity\x18\x02 \x01(\x0b\x32!.Ydb.DynamicConfig.ConfigIdentity\"B\n\x12\x44ropConfigResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"e\n\x18\x41\x64\x64VolatileConfigRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\t\"I\n\x19\x41\x64\x64VolatileConfigResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\",\n\x0eVolatileConfig\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\t\"M\n\x10GetConfigRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"A\n\x11GetConfigResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x93\x01\n\x0fGetConfigResult\x12\x0e\n\x06\x63onfig\x18\x01 \x01(\t\x12;\n\x10volatile_configs\x18\x02 \x03(\x0b\x32!.Ydb.DynamicConfig.VolatileConfig\x12\x33\n\x08identity\x18\x03 \x01(\x0b\x32!.Ydb.DynamicConfig.ConfigIdentity\"6\n\x16VolatileConfigMetadata\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x10\n\x08metadata\x18\x02 \x01(\t\"O\n\x12GetMetadataRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"C\n\x13GetMetadataResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"j\n\x11GetMetadataResult\x12\x10\n\x08metadata\x18\x01 \x01(\t\x12\x43\n\x10volatile_configs\x18\x02 \x03(\x0b\x32).Ydb.DynamicConfig.VolatileConfigMetadata\"\xb7\x02\n\x1bRemoveVolatileConfigRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x35\n\x08identity\x18\x02 \x01(\x0b\x32!.Ydb.DynamicConfig.ConfigIdentityH\x00\x12\x0f\n\x05\x66orce\x18\x03 \x01(\x08H\x00\x12I\n\x03ids\x18\x04 \x01(\x0b\x32:.Ydb.DynamicConfig.RemoveVolatileConfigRequest.IdsToDeleteH\x01\x12\r\n\x03\x61ll\x18\x05 \x01(\x08H\x01\x1a\x1a\n\x0bIdsToDelete\x12\x0b\n\x03ids\x18\x01 \x03(\x04\x42\x13\n\x11\x63onsistency_checkB\n\n\x08selector\"L\n\x1cRemoveVolatileConfigResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"b\n\x14GetNodeLabelsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0f\n\x07node_id\x18\x02 \x01(\r\")\n\tYamlLabel\x12\r\n\x05label\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"E\n\x15GetNodeLabelsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"C\n\x13GetNodeLabelsResult\x12,\n\x06labels\x18\x01 \x03(\x0b\x32\x1c.Ydb.DynamicConfig.YamlLabel\"\xcc\x01\n\x14ResolveConfigRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\t\x12;\n\x10volatile_configs\x18\x03 \x03(\x0b\x32!.Ydb.DynamicConfig.VolatileConfig\x12,\n\x06labels\x18\x04 \x03(\x0b\x32\x1c.Ydb.DynamicConfig.YamlLabel\"E\n\x15ResolveConfigResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"%\n\x13ResolveConfigResult\x12\x0e\n\x06\x63onfig\x18\x01 \x01(\t\"\xbb\x01\n\x17ResolveAllConfigRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\t\x12;\n\x10volatile_configs\x18\x03 \x03(\x0b\x32!.Ydb.DynamicConfig.VolatileConfig\x12\x18\n\x10verbose_response\x18\x04 \x01(\x08\"\xb6\x01\n\x0cYamlLabelExt\x12\r\n\x05label\x18\x01 \x01(\t\x12\x37\n\x04type\x18\x02 \x01(\x0e\x32).Ydb.DynamicConfig.YamlLabelExt.LabelType\x12\x12\n\x05value\x18\x03 \x01(\tH\x00\x88\x01\x01\"@\n\tLabelType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\n\n\x06\x43OMMON\x10\x01\x12\x0b\n\x07NOT_SET\x10\x02\x12\t\n\x05\x45MPTY\x10\x03\x42\x08\n\x06_value\";\n\x08LabelSet\x12/\n\x06labels\x18\x01 \x03(\x0b\x32\x1f.Ydb.DynamicConfig.YamlLabelExt\"Q\n\x0eResolvedConfig\x12/\n\nlabel_sets\x18\x01 \x03(\x0b\x32\x1b.Ydb.DynamicConfig.LabelSet\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\t\"H\n\x18ResolveAllConfigResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\\\n\x16ResolveAllConfigResult\x12\x0e\n\x06\x63onfig\x18\x01 \x01(\t\x12\x32\n\x07\x63onfigs\x18\x02 \x03(\x0b\x32!.Ydb.DynamicConfig.ResolvedConfigBo\n\"tech.ydb.proto.draft.dynamicconfigZFgithub.com/ydb-platform/ydb-go-genproto/draft/protos/Ydb_DynamicConfig\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[protos_dot_ydb__operation__pb2.DESCRIPTOR,])



_YAMLLABELEXT_LABELTYPE = _descriptor.EnumDescriptor(
  name='LabelType',
  full_name='Ydb.DynamicConfig.YamlLabelExt.LabelType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_SET', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMPTY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2895,
  serialized_end=2959,
)
_sym_db.RegisterEnumDescriptor(_YAMLLABELEXT_LABELTYPE)


_CONFIGIDENTITY = _descriptor.Descriptor(
  name='ConfigIdentity',
  full_name='Ydb.DynamicConfig.ConfigIdentity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='Ydb.DynamicConfig.ConfigIdentity.version', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster', full_name='Ydb.DynamicConfig.ConfigIdentity.cluster', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=88,
  serialized_end=138,
)


_SETCONFIGREQUEST = _descriptor.Descriptor(
  name='SetConfigRequest',
  full_name='Ydb.DynamicConfig.SetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.DynamicConfig.SetConfigRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='Ydb.DynamicConfig.SetConfigRequest.config', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dry_run', full_name='Ydb.DynamicConfig.SetConfigRequest.dry_run', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_unknown_fields', full_name='Ydb.DynamicConfig.SetConfigRequest.allow_unknown_fields', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=141,
  serialized_end=281,
)


_SETCONFIGRESPONSE = _descriptor.Descriptor(
  name='SetConfigResponse',
  full_name='Ydb.DynamicConfig.SetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.DynamicConfig.SetConfigResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=283,
  serialized_end=348,
)


_REPLACECONFIGREQUEST = _descriptor.Descriptor(
  name='ReplaceConfigRequest',
  full_name='Ydb.DynamicConfig.ReplaceConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.DynamicConfig.ReplaceConfigRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='Ydb.DynamicConfig.ReplaceConfigRequest.config', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dry_run', full_name='Ydb.DynamicConfig.ReplaceConfigRequest.dry_run', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_unknown_fields', full_name='Ydb.DynamicConfig.ReplaceConfigRequest.allow_unknown_fields', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=351,
  serialized_end=495,
)


_REPLACECONFIGRESPONSE = _descriptor.Descriptor(
  name='ReplaceConfigResponse',
  full_name='Ydb.DynamicConfig.ReplaceConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.DynamicConfig.ReplaceConfigResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=497,
  serialized_end=566,
)


_DROPCONFIGREQUEST = _descriptor.Descriptor(
  name='DropConfigRequest',
  full_name='Ydb.DynamicConfig.DropConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.DynamicConfig.DropConfigRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='identity', full_name='Ydb.DynamicConfig.DropConfigRequest.identity', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=569,
  serialized_end=700,
)


_DROPCONFIGRESPONSE = _descriptor.Descriptor(
  name='DropConfigResponse',
  full_name='Ydb.DynamicConfig.DropConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.DynamicConfig.DropConfigResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=702,
  serialized_end=768,
)


_ADDVOLATILECONFIGREQUEST = _descriptor.Descriptor(
  name='AddVolatileConfigRequest',
  full_name='Ydb.DynamicConfig.AddVolatileConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.DynamicConfig.AddVolatileConfigRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='Ydb.DynamicConfig.AddVolatileConfigRequest.config', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=770,
  serialized_end=871,
)


_ADDVOLATILECONFIGRESPONSE = _descriptor.Descriptor(
  name='AddVolatileConfigResponse',
  full_name='Ydb.DynamicConfig.AddVolatileConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.DynamicConfig.AddVolatileConfigResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=873,
  serialized_end=946,
)


_VOLATILECONFIG = _descriptor.Descriptor(
  name='VolatileConfig',
  full_name='Ydb.DynamicConfig.VolatileConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.DynamicConfig.VolatileConfig.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='Ydb.DynamicConfig.VolatileConfig.config', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=948,
  serialized_end=992,
)


_GETCONFIGREQUEST = _descriptor.Descriptor(
  name='GetConfigRequest',
  full_name='Ydb.DynamicConfig.GetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.DynamicConfig.GetConfigRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=994,
  serialized_end=1071,
)


_GETCONFIGRESPONSE = _descriptor.Descriptor(
  name='GetConfigResponse',
  full_name='Ydb.DynamicConfig.GetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.DynamicConfig.GetConfigResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1073,
  serialized_end=1138,
)


_GETCONFIGRESULT = _descriptor.Descriptor(
  name='GetConfigResult',
  full_name='Ydb.DynamicConfig.GetConfigResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='Ydb.DynamicConfig.GetConfigResult.config', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volatile_configs', full_name='Ydb.DynamicConfig.GetConfigResult.volatile_configs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='identity', full_name='Ydb.DynamicConfig.GetConfigResult.identity', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1141,
  serialized_end=1288,
)


_VOLATILECONFIGMETADATA = _descriptor.Descriptor(
  name='VolatileConfigMetadata',
  full_name='Ydb.DynamicConfig.VolatileConfigMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.DynamicConfig.VolatileConfigMetadata.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='Ydb.DynamicConfig.VolatileConfigMetadata.metadata', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1290,
  serialized_end=1344,
)


_GETMETADATAREQUEST = _descriptor.Descriptor(
  name='GetMetadataRequest',
  full_name='Ydb.DynamicConfig.GetMetadataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.DynamicConfig.GetMetadataRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1346,
  serialized_end=1425,
)


_GETMETADATARESPONSE = _descriptor.Descriptor(
  name='GetMetadataResponse',
  full_name='Ydb.DynamicConfig.GetMetadataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.DynamicConfig.GetMetadataResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1427,
  serialized_end=1494,
)


_GETMETADATARESULT = _descriptor.Descriptor(
  name='GetMetadataResult',
  full_name='Ydb.DynamicConfig.GetMetadataResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='Ydb.DynamicConfig.GetMetadataResult.metadata', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volatile_configs', full_name='Ydb.DynamicConfig.GetMetadataResult.volatile_configs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1496,
  serialized_end=1602,
)


_REMOVEVOLATILECONFIGREQUEST_IDSTODELETE = _descriptor.Descriptor(
  name='IdsToDelete',
  full_name='Ydb.DynamicConfig.RemoveVolatileConfigRequest.IdsToDelete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ids', full_name='Ydb.DynamicConfig.RemoveVolatileConfigRequest.IdsToDelete.ids', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1857,
  serialized_end=1883,
)

_REMOVEVOLATILECONFIGREQUEST = _descriptor.Descriptor(
  name='RemoveVolatileConfigRequest',
  full_name='Ydb.DynamicConfig.RemoveVolatileConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.DynamicConfig.RemoveVolatileConfigRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='identity', full_name='Ydb.DynamicConfig.RemoveVolatileConfigRequest.identity', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='force', full_name='Ydb.DynamicConfig.RemoveVolatileConfigRequest.force', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ids', full_name='Ydb.DynamicConfig.RemoveVolatileConfigRequest.ids', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='all', full_name='Ydb.DynamicConfig.RemoveVolatileConfigRequest.all', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_REMOVEVOLATILECONFIGREQUEST_IDSTODELETE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='consistency_check', full_name='Ydb.DynamicConfig.RemoveVolatileConfigRequest.consistency_check',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='selector', full_name='Ydb.DynamicConfig.RemoveVolatileConfigRequest.selector',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1605,
  serialized_end=1916,
)


_REMOVEVOLATILECONFIGRESPONSE = _descriptor.Descriptor(
  name='RemoveVolatileConfigResponse',
  full_name='Ydb.DynamicConfig.RemoveVolatileConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.DynamicConfig.RemoveVolatileConfigResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1918,
  serialized_end=1994,
)


_GETNODELABELSREQUEST = _descriptor.Descriptor(
  name='GetNodeLabelsRequest',
  full_name='Ydb.DynamicConfig.GetNodeLabelsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.DynamicConfig.GetNodeLabelsRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_id', full_name='Ydb.DynamicConfig.GetNodeLabelsRequest.node_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1996,
  serialized_end=2094,
)


_YAMLLABEL = _descriptor.Descriptor(
  name='YamlLabel',
  full_name='Ydb.DynamicConfig.YamlLabel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='Ydb.DynamicConfig.YamlLabel.label', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.DynamicConfig.YamlLabel.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2096,
  serialized_end=2137,
)


_GETNODELABELSRESPONSE = _descriptor.Descriptor(
  name='GetNodeLabelsResponse',
  full_name='Ydb.DynamicConfig.GetNodeLabelsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.DynamicConfig.GetNodeLabelsResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2139,
  serialized_end=2208,
)


_GETNODELABELSRESULT = _descriptor.Descriptor(
  name='GetNodeLabelsResult',
  full_name='Ydb.DynamicConfig.GetNodeLabelsResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='labels', full_name='Ydb.DynamicConfig.GetNodeLabelsResult.labels', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2210,
  serialized_end=2277,
)


_RESOLVECONFIGREQUEST = _descriptor.Descriptor(
  name='ResolveConfigRequest',
  full_name='Ydb.DynamicConfig.ResolveConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.DynamicConfig.ResolveConfigRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='Ydb.DynamicConfig.ResolveConfigRequest.config', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volatile_configs', full_name='Ydb.DynamicConfig.ResolveConfigRequest.volatile_configs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='Ydb.DynamicConfig.ResolveConfigRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2280,
  serialized_end=2484,
)


_RESOLVECONFIGRESPONSE = _descriptor.Descriptor(
  name='ResolveConfigResponse',
  full_name='Ydb.DynamicConfig.ResolveConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.DynamicConfig.ResolveConfigResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2486,
  serialized_end=2555,
)


_RESOLVECONFIGRESULT = _descriptor.Descriptor(
  name='ResolveConfigResult',
  full_name='Ydb.DynamicConfig.ResolveConfigResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='Ydb.DynamicConfig.ResolveConfigResult.config', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2557,
  serialized_end=2594,
)


_RESOLVEALLCONFIGREQUEST = _descriptor.Descriptor(
  name='ResolveAllConfigRequest',
  full_name='Ydb.DynamicConfig.ResolveAllConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.DynamicConfig.ResolveAllConfigRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='Ydb.DynamicConfig.ResolveAllConfigRequest.config', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volatile_configs', full_name='Ydb.DynamicConfig.ResolveAllConfigRequest.volatile_configs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='verbose_response', full_name='Ydb.DynamicConfig.ResolveAllConfigRequest.verbose_response', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2597,
  serialized_end=2784,
)


_YAMLLABELEXT = _descriptor.Descriptor(
  name='YamlLabelExt',
  full_name='Ydb.DynamicConfig.YamlLabelExt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='Ydb.DynamicConfig.YamlLabelExt.label', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='Ydb.DynamicConfig.YamlLabelExt.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.DynamicConfig.YamlLabelExt.value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _YAMLLABELEXT_LABELTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_value', full_name='Ydb.DynamicConfig.YamlLabelExt._value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2787,
  serialized_end=2969,
)


_LABELSET = _descriptor.Descriptor(
  name='LabelSet',
  full_name='Ydb.DynamicConfig.LabelSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='labels', full_name='Ydb.DynamicConfig.LabelSet.labels', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2971,
  serialized_end=3030,
)


_RESOLVEDCONFIG = _descriptor.Descriptor(
  name='ResolvedConfig',
  full_name='Ydb.DynamicConfig.ResolvedConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='label_sets', full_name='Ydb.DynamicConfig.ResolvedConfig.label_sets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='Ydb.DynamicConfig.ResolvedConfig.config', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3032,
  serialized_end=3113,
)


_RESOLVEALLCONFIGRESPONSE = _descriptor.Descriptor(
  name='ResolveAllConfigResponse',
  full_name='Ydb.DynamicConfig.ResolveAllConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.DynamicConfig.ResolveAllConfigResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3115,
  serialized_end=3187,
)


_RESOLVEALLCONFIGRESULT = _descriptor.Descriptor(
  name='ResolveAllConfigResult',
  full_name='Ydb.DynamicConfig.ResolveAllConfigResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='Ydb.DynamicConfig.ResolveAllConfigResult.config', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configs', full_name='Ydb.DynamicConfig.ResolveAllConfigResult.configs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3189,
  serialized_end=3281,
)

_SETCONFIGREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_SETCONFIGRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_REPLACECONFIGREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_REPLACECONFIGRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_DROPCONFIGREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_DROPCONFIGREQUEST.fields_by_name['identity'].message_type = _CONFIGIDENTITY
_DROPCONFIGRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_ADDVOLATILECONFIGREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_ADDVOLATILECONFIGRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_GETCONFIGREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_GETCONFIGRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_GETCONFIGRESULT.fields_by_name['volatile_configs'].message_type = _VOLATILECONFIG
_GETCONFIGRESULT.fields_by_name['identity'].message_type = _CONFIGIDENTITY
_GETMETADATAREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_GETMETADATARESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_GETMETADATARESULT.fields_by_name['volatile_configs'].message_type = _VOLATILECONFIGMETADATA
_REMOVEVOLATILECONFIGREQUEST_IDSTODELETE.containing_type = _REMOVEVOLATILECONFIGREQUEST
_REMOVEVOLATILECONFIGREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_REMOVEVOLATILECONFIGREQUEST.fields_by_name['identity'].message_type = _CONFIGIDENTITY
_REMOVEVOLATILECONFIGREQUEST.fields_by_name['ids'].message_type = _REMOVEVOLATILECONFIGREQUEST_IDSTODELETE
_REMOVEVOLATILECONFIGREQUEST.oneofs_by_name['consistency_check'].fields.append(
  _REMOVEVOLATILECONFIGREQUEST.fields_by_name['identity'])
_REMOVEVOLATILECONFIGREQUEST.fields_by_name['identity'].containing_oneof = _REMOVEVOLATILECONFIGREQUEST.oneofs_by_name['consistency_check']
_REMOVEVOLATILECONFIGREQUEST.oneofs_by_name['consistency_check'].fields.append(
  _REMOVEVOLATILECONFIGREQUEST.fields_by_name['force'])
_REMOVEVOLATILECONFIGREQUEST.fields_by_name['force'].containing_oneof = _REMOVEVOLATILECONFIGREQUEST.oneofs_by_name['consistency_check']
_REMOVEVOLATILECONFIGREQUEST.oneofs_by_name['selector'].fields.append(
  _REMOVEVOLATILECONFIGREQUEST.fields_by_name['ids'])
_REMOVEVOLATILECONFIGREQUEST.fields_by_name['ids'].containing_oneof = _REMOVEVOLATILECONFIGREQUEST.oneofs_by_name['selector']
_REMOVEVOLATILECONFIGREQUEST.oneofs_by_name['selector'].fields.append(
  _REMOVEVOLATILECONFIGREQUEST.fields_by_name['all'])
_REMOVEVOLATILECONFIGREQUEST.fields_by_name['all'].containing_oneof = _REMOVEVOLATILECONFIGREQUEST.oneofs_by_name['selector']
_REMOVEVOLATILECONFIGRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_GETNODELABELSREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_GETNODELABELSRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_GETNODELABELSRESULT.fields_by_name['labels'].message_type = _YAMLLABEL
_RESOLVECONFIGREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_RESOLVECONFIGREQUEST.fields_by_name['volatile_configs'].message_type = _VOLATILECONFIG
_RESOLVECONFIGREQUEST.fields_by_name['labels'].message_type = _YAMLLABEL
_RESOLVECONFIGRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_RESOLVEALLCONFIGREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_RESOLVEALLCONFIGREQUEST.fields_by_name['volatile_configs'].message_type = _VOLATILECONFIG
_YAMLLABELEXT.fields_by_name['type'].enum_type = _YAMLLABELEXT_LABELTYPE
_YAMLLABELEXT_LABELTYPE.containing_type = _YAMLLABELEXT
_YAMLLABELEXT.oneofs_by_name['_value'].fields.append(
  _YAMLLABELEXT.fields_by_name['value'])
_YAMLLABELEXT.fields_by_name['value'].containing_oneof = _YAMLLABELEXT.oneofs_by_name['_value']
_LABELSET.fields_by_name['labels'].message_type = _YAMLLABELEXT
_RESOLVEDCONFIG.fields_by_name['label_sets'].message_type = _LABELSET
_RESOLVEALLCONFIGRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_RESOLVEALLCONFIGRESULT.fields_by_name['configs'].message_type = _RESOLVEDCONFIG
DESCRIPTOR.message_types_by_name['ConfigIdentity'] = _CONFIGIDENTITY
DESCRIPTOR.message_types_by_name['SetConfigRequest'] = _SETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['SetConfigResponse'] = _SETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['ReplaceConfigRequest'] = _REPLACECONFIGREQUEST
DESCRIPTOR.message_types_by_name['ReplaceConfigResponse'] = _REPLACECONFIGRESPONSE
DESCRIPTOR.message_types_by_name['DropConfigRequest'] = _DROPCONFIGREQUEST
DESCRIPTOR.message_types_by_name['DropConfigResponse'] = _DROPCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['AddVolatileConfigRequest'] = _ADDVOLATILECONFIGREQUEST
DESCRIPTOR.message_types_by_name['AddVolatileConfigResponse'] = _ADDVOLATILECONFIGRESPONSE
DESCRIPTOR.message_types_by_name['VolatileConfig'] = _VOLATILECONFIG
DESCRIPTOR.message_types_by_name['GetConfigRequest'] = _GETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['GetConfigResponse'] = _GETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['GetConfigResult'] = _GETCONFIGRESULT
DESCRIPTOR.message_types_by_name['VolatileConfigMetadata'] = _VOLATILECONFIGMETADATA
DESCRIPTOR.message_types_by_name['GetMetadataRequest'] = _GETMETADATAREQUEST
DESCRIPTOR.message_types_by_name['GetMetadataResponse'] = _GETMETADATARESPONSE
DESCRIPTOR.message_types_by_name['GetMetadataResult'] = _GETMETADATARESULT
DESCRIPTOR.message_types_by_name['RemoveVolatileConfigRequest'] = _REMOVEVOLATILECONFIGREQUEST
DESCRIPTOR.message_types_by_name['RemoveVolatileConfigResponse'] = _REMOVEVOLATILECONFIGRESPONSE
DESCRIPTOR.message_types_by_name['GetNodeLabelsRequest'] = _GETNODELABELSREQUEST
DESCRIPTOR.message_types_by_name['YamlLabel'] = _YAMLLABEL
DESCRIPTOR.message_types_by_name['GetNodeLabelsResponse'] = _GETNODELABELSRESPONSE
DESCRIPTOR.message_types_by_name['GetNodeLabelsResult'] = _GETNODELABELSRESULT
DESCRIPTOR.message_types_by_name['ResolveConfigRequest'] = _RESOLVECONFIGREQUEST
DESCRIPTOR.message_types_by_name['ResolveConfigResponse'] = _RESOLVECONFIGRESPONSE
DESCRIPTOR.message_types_by_name['ResolveConfigResult'] = _RESOLVECONFIGRESULT
DESCRIPTOR.message_types_by_name['ResolveAllConfigRequest'] = _RESOLVEALLCONFIGREQUEST
DESCRIPTOR.message_types_by_name['YamlLabelExt'] = _YAMLLABELEXT
DESCRIPTOR.message_types_by_name['LabelSet'] = _LABELSET
DESCRIPTOR.message_types_by_name['ResolvedConfig'] = _RESOLVEDCONFIG
DESCRIPTOR.message_types_by_name['ResolveAllConfigResponse'] = _RESOLVEALLCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['ResolveAllConfigResult'] = _RESOLVEALLCONFIGRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ConfigIdentity = _reflection.GeneratedProtocolMessageType('ConfigIdentity', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGIDENTITY,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.ConfigIdentity)
  })
_sym_db.RegisterMessage(ConfigIdentity)

SetConfigRequest = _reflection.GeneratedProtocolMessageType('SetConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETCONFIGREQUEST,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.SetConfigRequest)
  })
_sym_db.RegisterMessage(SetConfigRequest)

SetConfigResponse = _reflection.GeneratedProtocolMessageType('SetConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETCONFIGRESPONSE,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.SetConfigResponse)
  })
_sym_db.RegisterMessage(SetConfigResponse)

ReplaceConfigRequest = _reflection.GeneratedProtocolMessageType('ReplaceConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _REPLACECONFIGREQUEST,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.ReplaceConfigRequest)
  })
_sym_db.RegisterMessage(ReplaceConfigRequest)

ReplaceConfigResponse = _reflection.GeneratedProtocolMessageType('ReplaceConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _REPLACECONFIGRESPONSE,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.ReplaceConfigResponse)
  })
_sym_db.RegisterMessage(ReplaceConfigResponse)

DropConfigRequest = _reflection.GeneratedProtocolMessageType('DropConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _DROPCONFIGREQUEST,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.DropConfigRequest)
  })
_sym_db.RegisterMessage(DropConfigRequest)

DropConfigResponse = _reflection.GeneratedProtocolMessageType('DropConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _DROPCONFIGRESPONSE,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.DropConfigResponse)
  })
_sym_db.RegisterMessage(DropConfigResponse)

AddVolatileConfigRequest = _reflection.GeneratedProtocolMessageType('AddVolatileConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDVOLATILECONFIGREQUEST,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.AddVolatileConfigRequest)
  })
_sym_db.RegisterMessage(AddVolatileConfigRequest)

AddVolatileConfigResponse = _reflection.GeneratedProtocolMessageType('AddVolatileConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _ADDVOLATILECONFIGRESPONSE,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.AddVolatileConfigResponse)
  })
_sym_db.RegisterMessage(AddVolatileConfigResponse)

VolatileConfig = _reflection.GeneratedProtocolMessageType('VolatileConfig', (_message.Message,), {
  'DESCRIPTOR' : _VOLATILECONFIG,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.VolatileConfig)
  })
_sym_db.RegisterMessage(VolatileConfig)

GetConfigRequest = _reflection.GeneratedProtocolMessageType('GetConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGREQUEST,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.GetConfigRequest)
  })
_sym_db.RegisterMessage(GetConfigRequest)

GetConfigResponse = _reflection.GeneratedProtocolMessageType('GetConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGRESPONSE,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.GetConfigResponse)
  })
_sym_db.RegisterMessage(GetConfigResponse)

GetConfigResult = _reflection.GeneratedProtocolMessageType('GetConfigResult', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGRESULT,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.GetConfigResult)
  })
_sym_db.RegisterMessage(GetConfigResult)

VolatileConfigMetadata = _reflection.GeneratedProtocolMessageType('VolatileConfigMetadata', (_message.Message,), {
  'DESCRIPTOR' : _VOLATILECONFIGMETADATA,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.VolatileConfigMetadata)
  })
_sym_db.RegisterMessage(VolatileConfigMetadata)

GetMetadataRequest = _reflection.GeneratedProtocolMessageType('GetMetadataRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMETADATAREQUEST,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.GetMetadataRequest)
  })
_sym_db.RegisterMessage(GetMetadataRequest)

GetMetadataResponse = _reflection.GeneratedProtocolMessageType('GetMetadataResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMETADATARESPONSE,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.GetMetadataResponse)
  })
_sym_db.RegisterMessage(GetMetadataResponse)

GetMetadataResult = _reflection.GeneratedProtocolMessageType('GetMetadataResult', (_message.Message,), {
  'DESCRIPTOR' : _GETMETADATARESULT,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.GetMetadataResult)
  })
_sym_db.RegisterMessage(GetMetadataResult)

RemoveVolatileConfigRequest = _reflection.GeneratedProtocolMessageType('RemoveVolatileConfigRequest', (_message.Message,), {

  'IdsToDelete' : _reflection.GeneratedProtocolMessageType('IdsToDelete', (_message.Message,), {
    'DESCRIPTOR' : _REMOVEVOLATILECONFIGREQUEST_IDSTODELETE,
    '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.RemoveVolatileConfigRequest.IdsToDelete)
    })
  ,
  'DESCRIPTOR' : _REMOVEVOLATILECONFIGREQUEST,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.RemoveVolatileConfigRequest)
  })
_sym_db.RegisterMessage(RemoveVolatileConfigRequest)
_sym_db.RegisterMessage(RemoveVolatileConfigRequest.IdsToDelete)

RemoveVolatileConfigResponse = _reflection.GeneratedProtocolMessageType('RemoveVolatileConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEVOLATILECONFIGRESPONSE,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.RemoveVolatileConfigResponse)
  })
_sym_db.RegisterMessage(RemoveVolatileConfigResponse)

GetNodeLabelsRequest = _reflection.GeneratedProtocolMessageType('GetNodeLabelsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNODELABELSREQUEST,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.GetNodeLabelsRequest)
  })
_sym_db.RegisterMessage(GetNodeLabelsRequest)

YamlLabel = _reflection.GeneratedProtocolMessageType('YamlLabel', (_message.Message,), {
  'DESCRIPTOR' : _YAMLLABEL,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.YamlLabel)
  })
_sym_db.RegisterMessage(YamlLabel)

GetNodeLabelsResponse = _reflection.GeneratedProtocolMessageType('GetNodeLabelsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETNODELABELSRESPONSE,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.GetNodeLabelsResponse)
  })
_sym_db.RegisterMessage(GetNodeLabelsResponse)

GetNodeLabelsResult = _reflection.GeneratedProtocolMessageType('GetNodeLabelsResult', (_message.Message,), {
  'DESCRIPTOR' : _GETNODELABELSRESULT,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.GetNodeLabelsResult)
  })
_sym_db.RegisterMessage(GetNodeLabelsResult)

ResolveConfigRequest = _reflection.GeneratedProtocolMessageType('ResolveConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESOLVECONFIGREQUEST,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.ResolveConfigRequest)
  })
_sym_db.RegisterMessage(ResolveConfigRequest)

ResolveConfigResponse = _reflection.GeneratedProtocolMessageType('ResolveConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESOLVECONFIGRESPONSE,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.ResolveConfigResponse)
  })
_sym_db.RegisterMessage(ResolveConfigResponse)

ResolveConfigResult = _reflection.GeneratedProtocolMessageType('ResolveConfigResult', (_message.Message,), {
  'DESCRIPTOR' : _RESOLVECONFIGRESULT,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.ResolveConfigResult)
  })
_sym_db.RegisterMessage(ResolveConfigResult)

ResolveAllConfigRequest = _reflection.GeneratedProtocolMessageType('ResolveAllConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESOLVEALLCONFIGREQUEST,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.ResolveAllConfigRequest)
  })
_sym_db.RegisterMessage(ResolveAllConfigRequest)

YamlLabelExt = _reflection.GeneratedProtocolMessageType('YamlLabelExt', (_message.Message,), {
  'DESCRIPTOR' : _YAMLLABELEXT,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.YamlLabelExt)
  })
_sym_db.RegisterMessage(YamlLabelExt)

LabelSet = _reflection.GeneratedProtocolMessageType('LabelSet', (_message.Message,), {
  'DESCRIPTOR' : _LABELSET,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.LabelSet)
  })
_sym_db.RegisterMessage(LabelSet)

ResolvedConfig = _reflection.GeneratedProtocolMessageType('ResolvedConfig', (_message.Message,), {
  'DESCRIPTOR' : _RESOLVEDCONFIG,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.ResolvedConfig)
  })
_sym_db.RegisterMessage(ResolvedConfig)

ResolveAllConfigResponse = _reflection.GeneratedProtocolMessageType('ResolveAllConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESOLVEALLCONFIGRESPONSE,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.ResolveAllConfigResponse)
  })
_sym_db.RegisterMessage(ResolveAllConfigResponse)

ResolveAllConfigResult = _reflection.GeneratedProtocolMessageType('ResolveAllConfigResult', (_message.Message,), {
  'DESCRIPTOR' : _RESOLVEALLCONFIGRESULT,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.ResolveAllConfigResult)
  })
_sym_db.RegisterMessage(ResolveAllConfigResult)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
from __future__ import annotations

import contextlib
import logging
import threading
import random
import itertools
import typing
from . import connection as conn_impl, driver, issues, settings as settings_impl, _apis


# Workaround for good IDE and universal for runtime
if typing.TYPE_CHECKING:
    from ._grpc.v4.protos import ydb_discovery_pb2
else:
    from ._grpc.common.protos import ydb_discovery_pb2


logger = logging.getLogger(__name__)


class EndpointInfo(object):
    __slots__ = (
        "address",
        "endpoint",
        "location",
        "port",
        "ssl",
        "ipv4_addrs",
        "ipv6_addrs",
        "ssl_target_name_override",
        "node_id",
    )

    def __init__(self, endpoint_info: ydb_discovery_pb2.EndpointInfo):
        self.address = endpoint_info.address
        self.endpoint = "%s:%s" % (endpoint_info.address, endpoint_info.port)
        self.location = endpoint_info.location
        self.port = endpoint_info.port
        self.ssl = endpoint_info.ssl
        self.ipv4_addrs = tuple(endpoint_info.ip_v4)
        self.ipv6_addrs = tuple(endpoint_info.ip_v6)
        self.ssl_target_name_override = endpoint_info.ssl_target_name_override
        self.node_id = endpoint_info.node_id

    def endpoints_with_options(self) -> typing.Generator[typing.Tuple[str, conn_impl.EndpointOptions], None, None]:
        ssl_target_name_override = None
        if self.ssl:
            if self.ssl_target_name_override:
                ssl_target_name_override = self.ssl_target_name_override
            elif self.ipv6_addrs or self.ipv4_addrs:
                ssl_target_name_override = self.address

        endpoint_options = conn_impl.EndpointOptions(
            ssl_target_name_override=ssl_target_name_override, node_id=self.node_id
        )

        if self.ipv6_addrs or self.ipv4_addrs:
            for ipv6addr in self.ipv6_addrs:
                yield ("ipv6:[%s]:%s" % (ipv6addr, self.port), endpoint_options)
            for ipv4addr in self.ipv4_addrs:
                yield ("ipv4:%s:%s" % (ipv4addr, self.port), endpoint_options)
        else:
            yield (self.endpoint, endpoint_options)

    def __str__(self):
        return "<Endpoint %s, location %s, ssl: %s>" % (
            self.endpoint,
            self.location,
            self.ssl,
        )

    def __repr__(self):
        return self.__str__()

    def __hash__(self):
        return hash(self.endpoint)

    def __eq__(self, other):
        if not hasattr(other, "endpoint"):
            return False

        return self.endpoint == other.endpoint


def _list_endpoints_request_factory(connection_params: driver.DriverConfig) -> _apis.ydb_discovery.ListEndpointsRequest:
    request = _apis.ydb_discovery.ListEndpointsRequest()
    request.database = connection_params.database
    return request


class DiscoveryResult(object):
    def __init__(self, self_location: str, endpoints: "list[EndpointInfo]"):
        self.self_location = self_location
        self.endpoints = endpoints

    def __str__(self):
        return "DiscoveryResult <self_location: %s, endpoints %s>" % (
            self.self_location,
            self.endpoints,
        )

    def __repr__(self):
        return self.__str__()

    @classmethod
    def from_response(
        cls,
        rpc_state: conn_impl._RpcState,
        response: ydb_discovery_pb2.ListEndpointsResponse,
        use_all_nodes: bool = False,
    ) -> DiscoveryResult:
        issues._process_response(response.operation)
        message = _apis.ydb_discovery.ListEndpointsResult()
        response.operation.result.Unpack(message)
        unique_local_endpoints = set()
        unique_different_endpoints = set()
        for info in message.endpoints:
            if info.location == message.self_location:
                unique_local_endpoints.add(EndpointInfo(info))
            else:
                unique_different_endpoints.add(EndpointInfo(info))

        result = []
        unique_local_endpoints = list(unique_local_endpoints)
        unique_different_endpoints = list(unique_different_endpoints)
        if use_all_nodes:
            result.extend(unique_local_endpoints)
            result.extend(unique_different_endpoints)
            random.shuffle(result)
        else:
            random.shuffle(unique_local_endpoints)
            random.shuffle(unique_different_endpoints)
            result.extend(unique_local_endpoints)
            result.extend(unique_different_endpoints)

        return cls(message.self_location, result)


class DiscoveryEndpointsResolver(object):
    def __init__(self, driver_config: driver.DriverConfig):
        self.logger = logger.getChild(self.__class__.__name__)
        self._driver_config = driver_config
        self._ready_timeout = getattr(self._driver_config, "discovery_request_timeout", 10)
        self._lock = threading.Lock()
        self._debug_details_history_size = 20
        self._debug_details_items = []
        self._endpoints = []
        self._endpoints.append(driver_config.endpoint)
        self._endpoints.extend(driver_config.endpoints)
        random.shuffle(self._endpoints)
        self._endpoints_iter = itertools.cycle(self._endpoints)

    def _add_debug_details(self, message: str, *args):
        self.logger.debug(message, *args)
        message = message % args
        with self._lock:
            self._debug_details_items.append(message)
            if len(self._debug_details_items) > self._debug_details_history_size:
                self._debug_details_items.pop()

    def debug_details(self) -> str:
        """
        Returns last resolver errors as a debug string.
        """
        with self._lock:
            return "\n".join(self._debug_details_items)

    def resolve(self) -> typing.ContextManager[typing.Optional[DiscoveryResult]]:
        with self.context_resolve() as result:
            return result

    @contextlib.contextmanager
    def context_resolve(self) -> typing.ContextManager[typing.Optional[DiscoveryResult]]:
        self.logger.debug("Preparing initial endpoint to resolve endpoints")
        endpoint = next(self._endpoints_iter)
        initial = conn_impl.Connection.ready_factory(endpoint, self._driver_config, ready_timeout=self._ready_timeout)
        if initial is None:
            self._add_debug_details(
                'Failed to establish connection to YDB discovery endpoint: "%s". Check endpoint correctness.' % endpoint
            )
            yield
            return

        self.logger.debug("Resolving endpoints for database %s", self._driver_config.database)
        try:
            resolved = initial(
                _list_endpoints_request_factory(self._driver_config),
                _apis.DiscoveryService.Stub,
                _apis.DiscoveryService.ListEndpoints,
                DiscoveryResult.from_response,
                settings=settings_impl.BaseRequestSettings().with_timeout(self._ready_timeout),
                wrap_args=(self._driver_config.use_all_nodes,),
            )

            self._add_debug_details(
                "Resolved endpoints for database %s: %s",
                self._driver_config.database,
                resolved,
            )

            yield resolved
        except Exception as e:

            self._add_debug_details(
                'Failed to resolve endpoints for database %s. Endpoint: "%s". Error details:\n %s',
                self._driver_config.database,
                endpoint,
                e,
            )

            yield

        finally:
            initial.close()



# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: draft/ydb_maintenance_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v5.draft.protos import ydb_maintenance_pb2 as draft_dot_protos_dot_ydb__maintenance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x64raft/ydb_maintenance_v1.proto\x12\x12Ydb.Maintenance.V1\x1a\"draft/protos/ydb_maintenance.proto2\x9c\x06\n\x12MaintenanceService\x12g\n\x10ListClusterNodes\x12(.Ydb.Maintenance.ListClusterNodesRequest\x1a).Ydb.Maintenance.ListClusterNodesResponse\x12p\n\x15\x43reateMaintenanceTask\x12-.Ydb.Maintenance.CreateMaintenanceTaskRequest\x1a(.Ydb.Maintenance.MaintenanceTaskResponse\x12r\n\x16RefreshMaintenanceTask\x12..Ydb.Maintenance.RefreshMaintenanceTaskRequest\x1a(.Ydb.Maintenance.MaintenanceTaskResponse\x12m\n\x12GetMaintenanceTask\x12*.Ydb.Maintenance.GetMaintenanceTaskRequest\x1a+.Ydb.Maintenance.GetMaintenanceTaskResponse\x12s\n\x14ListMaintenanceTasks\x12,.Ydb.Maintenance.ListMaintenanceTasksRequest\x1a-.Ydb.Maintenance.ListMaintenanceTasksResponse\x12r\n\x13\x44ropMaintenanceTask\x12+.Ydb.Maintenance.DropMaintenanceTaskRequest\x1a..Ydb.Maintenance.ManageMaintenanceTaskResponse\x12_\n\x0e\x43ompleteAction\x12&.Ydb.Maintenance.CompleteActionRequest\x1a%.Ydb.Maintenance.ManageActionResponseBd\n tech.ydb.proto.draft.maintenanceZ@github.com/ydb-platform/ydb-go-genproto/draft/Ydb_Maintenance_V1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'draft.ydb_maintenance_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n tech.ydb.proto.draft.maintenanceZ@github.com/ydb-platform/ydb-go-genproto/draft/Ydb_Maintenance_V1'
  _MAINTENANCESERVICE._serialized_start=91
  _MAINTENANCESERVICE._serialized_end=887
# @@protoc_insertion_point(module_scope)



from . import pool, scheme, table
import ydb
from .. import _utilities
from ydb.driver import get_config, default_credentials


class DriverConfig(ydb.DriverConfig):
    @classmethod
    def default_from_endpoint_and_database(cls, endpoint, database, root_certificates=None, credentials=None, **kwargs):
        return cls(
            endpoint,
            database,
            credentials=default_credentials(credentials),
            root_certificates=root_certificates,
            **kwargs
        )

    @classmethod
    def default_from_connection_string(cls, connection_string, root_certificates=None, credentials=None, **kwargs):
        endpoint, database = _utilities.parse_connection_string(connection_string)
        return cls(
            endpoint,
            database,
            credentials=default_credentials(credentials),
            root_certificates=root_certificates,
            **kwargs
        )


class Driver(pool.ConnectionPool):
    _credentials: ydb.Credentials  # used for topic clients

    def __init__(
        self,
        driver_config=None,
        connection_string=None,
        endpoint=None,
        database=None,
        root_certificates=None,
        credentials=None,
        **kwargs
    ):
        from .. import topic  # local import for prevent cycle import error
        from . import coordination  # local import for prevent cycle import error

        config = get_config(
            driver_config,
            connection_string,
            endpoint,
            database,
            root_certificates,
            credentials,
            config_class=DriverConfig,
        )

        super(Driver, self).__init__(config)

        self._credentials = config.credentials

        self.scheme_client = scheme.SchemeClient(self)
        self.table_client = table.TableClient(self, config.table_client_settings)
        self.topic_client = topic.TopicClientAsyncIO(self, config.topic_client_settings)
        self.coordination_client = coordination.CoordinationClient(self)

    async def stop(self, timeout=10):
        await self.table_client._stop_pool_if_needed(timeout=timeout)
        self.topic_client.close()
        await super().stop(timeout=timeout)



# -*- coding: utf-8 -*-


class BaseRequestSettings(object):
    __slots__ = (
        "trace_id",
        "request_type",
        "timeout",
        "cancel_after",
        "operation_timeout",
        "tracer",
        "compression",
        "headers",
        "need_rpc_auth",
    )

    def __init__(self):
        """
        Request settings to be used for RPC execution
        """
        self.trace_id = None
        self.request_type = None
        self.timeout = None
        self.cancel_after = None
        self.operation_timeout = None
        self.compression = None
        self.need_rpc_auth = True
        self.headers = []

    def make_copy(self):
        return (
            BaseRequestSettings()
            .with_trace_id(self.trace_id)
            .with_request_type(self.request_type)
            .with_timeout(self.timeout)
            .with_cancel_after(self.cancel_after)
            .with_operation_timeout(self.operation_timeout)
            .with_compression(self.compression)
            .with_need_rpc_auth(self.need_rpc_auth)
        )

    def with_compression(self, compression) -> "BaseRequestSettings":
        """
        Enables compression for the specific RPC
        :param compression: An RPCCompression enum value.
        :return The self instance.
        """
        self.compression = compression
        return self

    def with_need_rpc_auth(self, need_rpc_auth) -> "BaseRequestSettings":
        self.need_rpc_auth = need_rpc_auth
        return self

    def with_header(self, key, value) -> "BaseRequestSettings":
        """
        Adds a key-value pair to the request headers.
        :param key: A string with a header key.
        :param value: A string with a header value.
        :return The self instance.
        """
        self.headers.append((key, value))
        return self

    def with_trace_id(self, trace_id) -> "BaseRequestSettings":
        """
        Includes trace id for RPC headers
        :param trace_id: A trace id string
        :return: The self instance
        """
        self.trace_id = trace_id
        return self

    def with_request_type(self, request_type) -> "BaseRequestSettings":
        """
        Includes request type for RPC headers
        :param request_type: A request type string
        :return: The self instance
        """
        self.request_type = request_type
        return self

    def with_operation_timeout(self, timeout) -> "BaseRequestSettings":
        """
        Indicates that client is no longer interested in the result of operation after the specified duration
        starting from the time operation arrives at the server.
        Server will try to stop the execution of operation and if no result is currently available the operation
        will receive TIMEOUT status code, which will be sent back to client if it was waiting for the operation result.
        Timeout of operation does not tell anything about its result, it might be completed successfully
        or cancelled on server.
        :param timeout:
        :return: The self instance
        """
        self.operation_timeout = timeout
        return self

    def with_cancel_after(self, timeout) -> "BaseRequestSettings":
        """
        Server will try to cancel the operation after the specified duration starting from the time
        the operation arrives at server.
        In case of successful cancellation operation will receive CANCELLED status code, which will be
        sent back to client if it was waiting for the operation result.
        In case when cancellation isn't possible, no action will be performed.
        :param timeout:
        :return: The self instance
        """
        self.cancel_after = timeout
        return self

    def with_timeout(self, timeout) -> "BaseRequestSettings":
        """
        Client-side timeout to complete request.
        Since YDB doesn't support request cancellation at this moment, this feature should be
        used properly to avoid server overload.
        :param timeout: timeout value in seconds
        :return: The self instance
        """
        self.timeout = timeout
        return self



import asyncio
import logging
import time
import typing

from typing import (
    Any,
    Dict,
    List,
    Optional,
    Tuple,
)

import ydb

from ydb import issues, settings as settings_impl, table

from ydb.table import (
    BaseSession,
    BaseTableClient,
    _scan_query_request_factory,
    _wrap_scan_query_response,
    BaseTxContext,
    TableDescription,
)
from . import _utilities
from ydb import _apis, _session_impl

logger = logging.getLogger(__name__)


class Session(BaseSession):
    async def read_table(
        self,
        path,
        key_range=None,
        columns=(),
        ordered=False,
        row_limit=None,
        settings=None,
        use_snapshot=None,
    ):  # pylint: disable=W0236
        request = _session_impl.read_table_request_factory(
            self._state,
            path,
            key_range,
            columns,
            ordered,
            row_limit,
            use_snapshot=use_snapshot,
        )
        stream_it = await self._driver(
            request,
            _apis.TableService.Stub,
            _apis.TableService.StreamReadTable,
            settings=settings,
        )
        return _utilities.AsyncResponseIterator(stream_it, _session_impl.wrap_read_table_response)

    async def keep_alive(self, settings=None):  # pylint: disable=W0236
        return await super().keep_alive(settings)

    async def create(self, settings=None):  # pylint: disable=W0236
        res = super().create(settings)
        if asyncio.iscoroutine(res):
            res = await res
        return res

    async def delete(self, settings=None):  # pylint: disable=W0236
        return await super().delete(settings)

    async def execute_scheme(self, yql_text, settings=None):  # pylint: disable=W0236
        return await super().execute_scheme(yql_text, settings)

    async def prepare(self, query, settings=None):  # pylint: disable=W0236
        res = super().prepare(query, settings)
        if asyncio.iscoroutine(res):
            res = await res
        return res

    async def explain(self, yql_text, settings=None):  # pylint: disable=W0236
        return await super().explain(yql_text, settings)

    async def create_table(self, path, table_description, settings=None):  # pylint: disable=W0236
        return await super().create_table(path, table_description, settings)

    async def drop_table(self, path, settings=None):  # pylint: disable=W0236
        return await super().drop_table(path, settings)

    async def alter_table(
        self,
        path,
        add_columns=None,
        drop_columns=None,
        settings=None,
        alter_attributes=None,
        add_indexes=None,
        drop_indexes=None,
        set_ttl_settings=None,
        drop_ttl_settings=None,
        add_column_families=None,
        alter_column_families=None,
        alter_storage_settings=None,
        set_compaction_policy=None,
        alter_partitioning_settings=None,
        set_key_bloom_filter=None,
        set_read_replicas_settings=None,
        rename_indexes=None,
    ):  # pylint: disable=W0236,R0913,R0914
        return await super().alter_table(
            path,
            add_columns,
            drop_columns,
            settings,
            alter_attributes,
            add_indexes,
            drop_indexes,
            set_ttl_settings,
            drop_ttl_settings,
            add_column_families,
            alter_column_families,
            alter_storage_settings,
            set_compaction_policy,
            alter_partitioning_settings,
            set_key_bloom_filter,
            set_read_replicas_settings,
            rename_indexes,
        )

    def transaction(self, tx_mode=None, *, allow_split_transactions=None):
        return TxContext(
            self._driver,
            self._state,
            self,
            tx_mode,
            allow_split_transactions=allow_split_transactions,
        )

    async def describe_table(self, path, settings=None):  # pylint: disable=W0236
        return await super().describe_table(path, settings)

    async def copy_table(self, source_path, destination_path, settings=None):  # pylint: disable=W0236
        return await super().copy_table(source_path, destination_path, settings)

    async def copy_tables(self, source_destination_pairs, settings=None):  # pylint: disable=W0236
        return await super().copy_tables(source_destination_pairs, settings)

    async def rename_tables(self, rename_items, settings=None):  # pylint: disable=W0236
        return await super().rename_tables(rename_items, settings)


class TableClient(BaseTableClient):
    def __init__(self, driver, table_client_settings=None):
        # type:(ydb.Driver, ydb.TableClientSettings) -> None
        super().__init__(driver=driver, table_client_settings=table_client_settings)
        self._pool: Optional[SessionPool] = None

    def __del__(self):
        if self._pool is not None and not self._pool._terminating:
            try:
                asyncio.get_running_loop().create_task(self._stop_pool_if_needed())
            except Exception:
                pass

    def session(self):
        return Session(self._driver, self._table_client_settings)

    async def bulk_upsert(self, *args, **kwargs):  # pylint: disable=W0236
        return await super().bulk_upsert(*args, **kwargs)

    async def scan_query(self, query, parameters=None, settings=None):  # pylint: disable=W0236
        request = _scan_query_request_factory(query, parameters, settings)
        response = await self._driver(
            request,
            _apis.TableService.Stub,
            _apis.TableService.StreamExecuteScanQuery,
            settings=settings,
        )
        return _utilities.AsyncResponseIterator(
            response,
            lambda resp: _wrap_scan_query_response(resp, self._table_client_settings),
        )

    def _init_pool_if_needed(self):
        if self._pool is None:
            self._pool = SessionPool(self._driver, 10)

    async def _stop_pool_if_needed(self, timeout=10):
        if self._pool is not None and not self._pool._terminating:
            await self._pool.stop(timeout=timeout)
            self._pool = None

    async def create_table(
        self,
        path: str,
        table_description: "TableDescription",
        settings: Optional["settings_impl.BaseRequestSettings"] = None,
    ) -> "ydb.Operation":
        """
        Create a YDB table.

        :param path: A table path
        :param table_description: TableDescription instanse.
        :param settings: An instance of BaseRequestSettings that describes how rpc should be invoked.

        :return: Operation or YDB error otherwise.
        """

        self._init_pool_if_needed()

        async def callee(session: Session):
            return await session.create_table(path=path, table_description=table_description, settings=settings)

        return await self._pool.retry_operation(callee)

    async def drop_table(
        self,
        path: str,
        settings: Optional["settings_impl.BaseRequestSettings"] = None,
    ) -> "ydb.Operation":
        """
        Drop a YDB table.

        :param path: A table path
        :param settings: An instance of BaseRequestSettings that describes how rpc should be invoked.

        :return: Operation or YDB error otherwise.
        """

        self._init_pool_if_needed()

        async def callee(session: Session):
            return await session.drop_table(path=path, settings=settings)

        return await self._pool.retry_operation(callee)

    async def alter_table(
        self,
        path: str,
        add_columns: Optional[List["ydb.Column"]] = None,
        drop_columns: Optional[List[str]] = None,
        settings: Optional["settings_impl.BaseRequestSettings"] = None,
        alter_attributes: Optional[Optional[Dict[str, str]]] = None,
        add_indexes: Optional[List["ydb.TableIndex"]] = None,
        drop_indexes: Optional[List[str]] = None,
        set_ttl_settings: Optional["ydb.TtlSettings"] = None,
        drop_ttl_settings: Optional[Any] = None,
        add_column_families: Optional[List["ydb.ColumnFamily"]] = None,
        alter_column_families: Optional[List["ydb.ColumnFamily"]] = None,
        alter_storage_settings: Optional["ydb.StorageSettings"] = None,
        set_compaction_policy: Optional[str] = None,
        alter_partitioning_settings: Optional["ydb.PartitioningSettings"] = None,
        set_key_bloom_filter: Optional["ydb.FeatureFlag"] = None,
        set_read_replicas_settings: Optional["ydb.ReadReplicasSettings"] = None,
        rename_indexes: Optional[List["ydb.RenameIndexItem"]] = None,
    ) -> "ydb.Operation":
        """
        Alter a YDB table.

        :param path: A table path
        :param add_columns: List of ydb.Column to add
        :param drop_columns: List of column names to drop
        :param settings: An instance of BaseRequestSettings that describes how rpc should be invoked.
        :param alter_attributes: Dict of attributes to alter
        :param add_indexes: List of ydb.TableIndex to add
        :param drop_indexes: List of index names to drop
        :param set_ttl_settings: ydb.TtlSettings to set
        :param drop_ttl_settings: Any to drop
        :param add_column_families: List of ydb.ColumnFamily to add
        :param alter_column_families: List of ydb.ColumnFamily to alter
        :param alter_storage_settings: ydb.StorageSettings to alter
        :param set_compaction_policy: Compaction policy
        :param alter_partitioning_settings: ydb.PartitioningSettings to alter
        :param set_key_bloom_filter: ydb.FeatureFlag to set key bloom filter
        :param rename_indexes: List of ydb.RenameIndexItem to rename

        :return: Operation or YDB error otherwise.
        """

        self._init_pool_if_needed()

        async def callee(session: Session):
            return await session.alter_table(
                path=path,
                add_columns=add_columns,
                drop_columns=drop_columns,
                settings=settings,
                alter_attributes=alter_attributes,
                add_indexes=add_indexes,
                drop_indexes=drop_indexes,
                set_ttl_settings=set_ttl_settings,
                drop_ttl_settings=drop_ttl_settings,
                add_column_families=add_column_families,
                alter_column_families=alter_column_families,
                alter_storage_settings=alter_storage_settings,
                set_compaction_policy=set_compaction_policy,
                alter_partitioning_settings=alter_partitioning_settings,
                set_key_bloom_filter=set_key_bloom_filter,
                set_read_replicas_settings=set_read_replicas_settings,
                rename_indexes=rename_indexes,
            )

        return await self._pool.retry_operation(callee)

    async def describe_table(
        self,
        path: str,
        settings: Optional["settings_impl.BaseRequestSettings"] = None,
    ) -> "ydb.TableSchemeEntry":
        """
        Describe a YDB table.

        :param path: A table path
        :param settings: An instance of BaseRequestSettings that describes how rpc should be invoked.

        :return: TableSchemeEntry or YDB error otherwise.
        """

        self._init_pool_if_needed()

        async def callee(session: Session):
            return await session.describe_table(path=path, settings=settings)

        return await self._pool.retry_operation(callee)

    async def copy_table(
        self,
        source_path: str,
        destination_path: str,
        settings: Optional["settings_impl.BaseRequestSettings"] = None,
    ) -> "ydb.Operation":
        """
        Copy a YDB table.

        :param source_path: A table path
        :param destination_path: Destination table path
        :param settings: An instance of BaseRequestSettings that describes how rpc should be invoked.

        :return: Operation or YDB error otherwise.
        """

        self._init_pool_if_needed()

        async def callee(session: Session):
            return await session.copy_table(
                source_path=source_path,
                destination_path=destination_path,
                settings=settings,
            )

        return await self._pool.retry_operation(callee)

    async def copy_tables(
        self,
        source_destination_pairs: List[Tuple[str, str]],
        settings: Optional["settings_impl.BaseRequestSettings"] = None,
    ) -> "ydb.Operation":
        """
        Copy a YDB tables.

        :param source_destination_pairs: List of tuples (source_path, destination_path)
        :param settings: An instance of BaseRequestSettings that describes how rpc should be invoked.

        :return: Operation or YDB error otherwise.
        """

        self._init_pool_if_needed()

        async def callee(session: Session):
            return await session.copy_tables(source_destination_pairs=source_destination_pairs, settings=settings)

        return await self._pool.retry_operation(callee)

    async def rename_tables(
        self,
        rename_items: List[Tuple[str, str]],
        settings: Optional["settings_impl.BaseRequestSettings"] = None,
    ) -> "ydb.Operation":
        """
        Rename a YDB tables.

        :param rename_items: List of tuples (current_name, desired_name)
        :param settings: An instance of BaseRequestSettings that describes how rpc should be invoked.

        :return: Operation or YDB error otherwise.
        """

        self._init_pool_if_needed()

        async def callee(session: Session):
            return await session.rename_tables(rename_items=rename_items, settings=settings)

        return await self._pool.retry_operation(callee)


class TxContext(BaseTxContext):
    async def __aenter__(self):
        return self

    async def __aexit__(self, exc_type, exc_val, exc_tb):
        if self._tx_state.tx_id is not None:
            # It's strictly recommended to close transactions directly
            # by using commit_tx=True flag while executing statement or by
            # .commit() or .rollback() methods, but here we trying to do best
            # effort to avoid useless open transactions
            logger.warning("Potentially leaked tx: %s", self._tx_state.tx_id)
            try:
                await self.rollback()
            except issues.Error:
                logger.warning("Failed to rollback leaked tx: %s", self._tx_state.tx_id)

            self._tx_state.tx_id = None

    async def execute(self, query, parameters=None, commit_tx=False, settings=None):  # pylint: disable=W0236

        return await super().execute(query, parameters, commit_tx, settings)

    async def commit(self, settings=None):  # pylint: disable=W0236
        res = super().commit(settings)
        if asyncio.iscoroutine(res):
            res = await res
        return res

    async def rollback(self, settings=None):  # pylint: disable=W0236
        res = super().rollback(settings)
        if asyncio.iscoroutine(res):
            res = await res
        return res

    async def begin(self, settings=None):  # pylint: disable=W0236
        res = super().begin(settings)
        if asyncio.iscoroutine(res):
            res = await res
        return res


async def retry_operation(callee, retry_settings=None, *args, **kwargs):  # pylint: disable=W1113
    """
    The retry operation helper can be used to retry a coroutine that raises YDB specific
    exceptions.

    :param callee: A coroutine to retry.
    :param retry_settings: An instance of ydb.RetrySettings that describes how the coroutine
    should be retried. If None, default instance of retry settings will be used.
    :param args: A tuple with positional arguments to be passed into the coroutine.
    :param kwargs: A dictionary with keyword arguments to be passed into the coroutine.

    Returns awaitable result of coroutine. If retries are not succussful exception is raised.
    """

    opt_generator = ydb.retry_operation_impl(callee, retry_settings, *args, **kwargs)
    for next_opt in opt_generator:
        if isinstance(next_opt, ydb.YdbRetryOperationSleepOpt):
            await asyncio.sleep(next_opt.timeout)
        else:
            try:
                return await next_opt.result
            except BaseException as e:  # pylint: disable=W0703
                next_opt.set_exception(e)


class SessionCheckout:
    __slots__ = ("_acquired", "_pool", "_blocking", "_timeout", "_retry_timeout")

    def __init__(self, pool, timeout, retry_timeout):
        """
        A context manager that checkouts a session from the specified pool and
        returns it on manager exit.
        :param pool: A SessionPool instance
        :param blocking: A flag that specifies that session acquire method should blocks
        :param timeout: A timeout in seconds for session acquire
        """
        self._pool: SessionPool = pool
        self._acquired = None
        self._timeout = timeout
        self._retry_timeout = retry_timeout

    async def __aenter__(self):
        self._acquired = await self._pool.acquire(self._timeout, self._retry_timeout)
        return self._acquired

    async def __aexit__(self, exc_type, exc_val, exc_tb):
        if self._acquired is not None:
            await self._pool.release(self._acquired)


class SessionPool:
    def __init__(self, driver: "ydb.aio.Driver", size: int, min_pool_size: int = 0):
        self._driver_await_timeout = 3
        self._should_stop = asyncio.Event()
        self._waiters = 0
        self._driver = driver
        self._active_queue = asyncio.PriorityQueue()
        self._active_count = 0
        self._size = size
        self._req_settings = settings_impl.BaseRequestSettings().with_timeout(3)
        self._logger = logger.getChild(self.__class__.__name__)
        self._min_pool_size = min_pool_size
        self._keep_alive_threshold = 4 * 60
        self._terminating = False
        self._init_session_timeout = 20

        self._keep_alive_task = asyncio.ensure_future(self._keep_alive_loop())

        self._min_pool_tasks = []

        for _ in range(self._min_pool_size):
            self._min_pool_tasks.append(asyncio.ensure_future(self._init_and_put(self._init_session_timeout)))

    async def retry_operation(
        self, callee: typing.Callable, *args, retry_settings: table.RetrySettings = None, **kwargs
    ):

        if retry_settings is None:
            retry_settings = table.RetrySettings()

        async def wrapper_callee():
            async with self.checkout(timeout=retry_settings.get_session_client_timeout) as session:
                return await callee(session, *args, **kwargs)

        return await retry_operation(wrapper_callee, retry_settings)

    def _create(self) -> Session:
        self._active_count += 1
        session = self._driver.table_client.session()
        self._logger.debug("Created session %s", session)
        return session

    async def _init_session_logic(self, session: ydb.ISession) -> typing.Optional[ydb.ISession]:
        try:
            await self._driver.wait(self._driver_await_timeout)
            session = await session.create(self._req_settings)
            return session
        except issues.Error as e:
            self._logger.error("Failed to create session. Reason: %s", str(e))
        except Exception as e:  # pylint: disable=W0703
            self._logger.exception("Failed to create session. Reason: %s", str(e))
        except BaseException as e:  # pylint: disable=W0703
            self._logger.exception("Failed to create session. Reason (base exception): %s", str(e))
            raise

        return None

    async def _init_session(self, session: ydb.ISession, retry_num: int = None) -> typing.Optional[ydb.ISession]:
        """
        :param retry_num: Number of retries. If None - retries until success.
        :return:
        """
        i = 0
        while retry_num is None or i < retry_num:
            curr_sess = await self._init_session_logic(session)
            if curr_sess:
                return curr_sess
            i += 1
        return None

    async def _prepare_session(self, timeout, retry_num) -> ydb.ISession:
        session = self._create()
        try:
            new_sess = await asyncio.wait_for(self._init_session(session, retry_num=retry_num), timeout=timeout)
            if not new_sess:
                self._destroy(session)
            return new_sess
        except BaseException as e:
            self._destroy(session)
            raise e

    async def _get_session_from_queue(self, timeout: float):
        task_wait = asyncio.ensure_future(asyncio.wait_for(self._active_queue.get(), timeout=timeout))
        task_should_stop = asyncio.ensure_future(self._should_stop.wait())
        try:
            done, _ = await asyncio.wait((task_wait, task_should_stop), return_when=asyncio.FIRST_COMPLETED)
        except asyncio.CancelledError:
            task_should_stop.cancel()
            cancelled = task_wait.cancel()
            if not cancelled and not task_wait.exception():
                priority, session = task_wait.result()
                self._active_queue.put_nowait((priority, session))
            raise
        if task_should_stop in done:
            task_wait.cancel()
            return self._create()
        _, session = task_wait.result()
        return session

    async def acquire(self, timeout: float = None, retry_timeout: float = None, retry_num: int = None) -> Session:

        if self._should_stop.is_set():
            self._logger.error("Take session from closed session pool")
            raise ValueError("Take session from closed session pool.")

        if retry_timeout is None:
            retry_timeout = timeout

        try:
            _, session = self._active_queue.get_nowait()
            self._logger.debug("Acquired active session from queue: %s", session.session_id)
            return session
        except asyncio.QueueEmpty:
            pass

        if self._active_count < self._size:
            self._logger.debug(
                "Session pool is not large enough (active_count < size: %d < %d). " "will create a new session.",
                self._active_count,
                self._size,
            )
            try:
                session = await self._prepare_session(timeout=retry_timeout, retry_num=retry_num)
            except asyncio.TimeoutError:
                raise issues.SessionPoolEmpty("Timeout when creating session") from None

            if session is not None:
                self._logger.debug("Acquired new created session: %s", session.session_id)
                return session

        try:
            self._waiters += 1
            session = await self._get_session_from_queue(timeout)
            return session
        except asyncio.TimeoutError:
            raise issues.SessionPoolEmpty("Timeout when wait") from None
        finally:
            self._waiters -= 1

    def _is_min_pool_size_satisfied(self, delta=0):
        if self._terminating:
            return True
        return self._active_count + delta >= self._min_pool_size

    async def _init_and_put(self, timeout=10):
        sess = await self._prepare_session(timeout=timeout, retry_num=None)
        await self.release(session=sess)

    def _destroy(self, session: ydb.ISession, wait_for_del: bool = False):
        self._logger.debug("Requested session destroy: %s.", session)
        self._active_count -= 1
        self._logger.debug(
            "Session %s is no longer active. Current active count %d.",
            session,
            self._active_count,
        )

        if self._waiters > 0 or not self._is_min_pool_size_satisfied():
            asyncio.ensure_future(self._init_and_put(self._init_session_timeout))

        if session.initialized():
            coro = session.delete(self._req_settings)
            if wait_for_del:
                self._logger.debug("Sent delete on session %s", session)
                return coro
            else:
                asyncio.ensure_future(coro)
        return None

    async def release(self, session: Session):
        self._release_nowait(session)

    def _release_nowait(self, session: Session):
        self._logger.debug("Put on session %s", session.session_id)
        if session.closing():
            self._destroy(session)
            return False

        if session.pending_query():
            self._destroy(session)
            return False
        if not session.initialized() or self._should_stop.is_set():
            self._destroy(session)
            return False

        # self._active_queue has no size limit, it means that put_nowait will be successfully always
        self._active_queue.put_nowait((time.time() + 10 * 60, session))
        self._logger.debug("Session returned to queue: %s", session.session_id)

    async def _pick_for_keepalive(self):
        try:
            priority, session = self._active_queue.get_nowait()
        except asyncio.QueueEmpty:
            return None

        till_expire = priority - time.time()
        if till_expire < self._keep_alive_threshold:
            return session
        await self._active_queue.put((priority, session))
        return None

    async def _send_keep_alive(self, session: ydb.ISession):
        if session is None:
            return False
        if self._should_stop.is_set():
            self._destroy(session)
            return False
        await session.keep_alive(self._req_settings)
        try:
            await self.release(session)
        except BaseException:  # pylint: disable=W0703
            self._destroy(session)

    async def _keep_alive_loop(self):
        while True:
            try:
                await asyncio.wait_for(self._should_stop.wait(), timeout=self._keep_alive_threshold // 4)
                break
            except asyncio.TimeoutError:
                while True:
                    session = await self._pick_for_keepalive()
                    if not session:
                        break
                    asyncio.ensure_future(self._send_keep_alive(session))

    async def stop(self, timeout=None):
        self._logger.debug("Requested session pool stop.")
        self._should_stop.set()
        self._terminating = True

        for task in self._min_pool_tasks:
            task.cancel()

        self._logger.debug("Destroying sessions in active queue")

        tasks = []

        while True:
            try:
                _, session = self._active_queue.get_nowait()
                tasks.append(self._destroy(session, wait_for_del=True))

            except asyncio.QueueEmpty:
                break

        await asyncio.gather(*tasks)

        self._logger.debug("Destroyed active sessions")

        await asyncio.wait_for(self._keep_alive_task, timeout=timeout)

    async def __aenter__(self):
        return self

    async def __aexit__(self, exc_type, exc, tb):
        await self.stop()

    async def wait_until_min_size(self):
        await asyncio.gather(*self._min_pool_tasks)

    def checkout(self, timeout: float = None, retry_timeout: float = None):
        return SessionCheckout(self, timeout, retry_timeout=retry_timeout)



import enum
import typing

from . import _apis

from . import settings_impl as s_impl

# Workaround for good IDE and universal for runtime
if typing.TYPE_CHECKING:
    from ._grpc.v4.protos import ydb_export_pb2
    from ._grpc.v4 import ydb_export_v1_pb2_grpc
else:
    from ._grpc.common.protos import ydb_export_pb2
    from ._grpc.common import ydb_export_v1_pb2_grpc

from . import operation

_ExportToYt = "ExportToYt"
_ExportToS3 = "ExportToS3"
_progresses = {}


@enum.unique
class ExportProgress(enum.IntEnum):
    UNSPECIFIED = 0
    PREPARING = 1
    TRANSFER_DATA = 2
    DONE = 3
    CANCELLATION = 4
    CANCELLED = 5


def _initialize_progresses():
    for key, value in ydb_export_pb2.ExportProgress.Progress.items():
        _progresses[value] = getattr(ExportProgress, key[len("PROGRESS_") :])


_initialize_progresses()


class ExportToYTOperation(operation.Operation):
    def __init__(self, rpc_state, response, driver):
        super(ExportToYTOperation, self).__init__(rpc_state, response, driver)
        metadata = ydb_export_pb2.ExportToYtMetadata()
        response.operation.metadata.Unpack(metadata)
        self.progress = _progresses.get(metadata.progress)
        self.items_progress = metadata.items_progress

    def __str__(self):
        return "ExportToYTOperation<id: %s, progress: %s>" % (
            self.id,
            self.progress.name,
        )

    def __repr__(self):
        return self.__str__()


class ExportToS3Operation(operation.Operation):
    def __init__(self, rpc_state, response, driver):
        super(ExportToS3Operation, self).__init__(rpc_state, response, driver)
        metadata = ydb_export_pb2.ExportToS3Metadata()
        response.operation.metadata.Unpack(metadata)
        self.progress = _progresses.get(metadata.progress)
        self.items_progress = metadata.items_progress

    def __str__(self):
        return "ExportToS3Operation<id: %s, progress: %s>" % (
            self.id,
            self.progress.name,
        )

    def __repr__(self):
        return self.__str__()


class ExportToYTSettings(s_impl.BaseRequestSettings):
    def __init__(self):
        super(ExportToYTSettings, self).__init__()
        self.items = []
        self.number_of_retries = 0
        self.token = None
        self.host = None
        self.port = None
        self.uid = None
        self.use_type_v3 = False

    def with_port(self, port):
        self.port = port
        return self

    def with_host(self, host):
        self.host = host
        return self

    def with_uid(self, uid):
        self.uid = uid
        return self

    def with_token(self, token):
        self.token = token
        return self

    def with_item(self, item):
        """
        :param: A source & destination tuple to export.
        """
        self.items.append(item)
        return self

    def with_source_and_destination(self, source_path, destination_path):
        return self.with_item((source_path, destination_path))

    def with_number_of_retries(self, number_of_retries):
        self.number_of_retries = number_of_retries
        return self

    def with_items(self, *items):
        self.items.extend(items)
        return self

    def with_use_type_v3(self, use_type_v3):
        self.use_type_v3 = use_type_v3
        return self


class ExportToS3Settings(s_impl.BaseRequestSettings):
    def __init__(self):
        super(ExportToS3Settings, self).__init__()
        self.items = []
        self.bucket = None
        self.endpoint = None
        self.scheme = 2
        self.uid = None
        self.access_key = None
        self.secret_key = None
        self.number_of_retries = 0
        self.storage_class = None
        self.export_compression = None

    def with_scheme(self, scheme):
        self.scheme = scheme
        return self

    def with_storage_class(self, storage_class):
        self.storage_class = storage_class
        return self

    def with_export_compression(self, compression):
        self.export_compression = compression
        return self

    def with_bucket(self, bucket):
        self.bucket = bucket
        return self

    def with_endpoint(self, endpoint):
        self.endpoint = endpoint
        return self

    def with_access_key(self, access_key):
        self.access_key = access_key
        return self

    def with_uid(self, uid):
        self.uid = uid
        return self

    def with_secret_key(self, secret_key):
        self.secret_key = secret_key
        return self

    def with_number_of_retries(self, number_of_retries):
        self.number_of_retries = number_of_retries
        return self

    def with_source_and_destination(self, source_path, destination_prefix):
        return self.with_item((source_path, destination_prefix))

    def with_item(self, item):
        self.items.append(item)
        return self

    def with_items(self, *items):
        self.items.extend(items)
        return self


def _export_to_yt_request_factory(settings):
    request = ydb_export_pb2.ExportToYtRequest(
        settings=ydb_export_pb2.ExportToYtSettings(host=settings.host, token=settings.token)
    )

    if settings.number_of_retries > 0:
        request.settings.number_of_retries = settings.number_of_retries

    if settings.port:
        request.settings.port = settings.port

    if settings.use_type_v3:
        request.settings.use_type_v3 = settings.use_type_v3

    for source_path, destination_path in settings.items:
        request.settings.items.add(source_path=source_path, destination_path=destination_path)

    return request


def _get_operation_request(operation_id):
    request = _apis.ydb_operation.GetOperationRequest(id=operation_id)
    return request


def _export_to_s3_request_factory(settings):
    request = ydb_export_pb2.ExportToS3Request(
        settings=ydb_export_pb2.ExportToS3Settings(
            endpoint=settings.endpoint,
            bucket=settings.bucket,
            access_key=settings.access_key,
            secret_key=settings.secret_key,
            scheme=settings.scheme,
            storage_class=settings.storage_class,
        )
    )

    if settings.uid is not None:
        request.operation_params.labels["uid"] = settings.uid

    if settings.number_of_retries > 0:
        request.settings.number_of_retries = settings.number_of_retries

    if settings.export_compression is not None:
        request.settings.compression = settings.export_compression

    for source_path, destination_prefix in settings.items:
        request.settings.items.add(
            source_path=source_path,
            destination_prefix=destination_prefix,
        )

    return request


class ExportClient(object):
    def __init__(self, driver):
        self._driver = driver

    def get_export_to_s3_operation(self, operation_id, settings=None):
        return self._driver(
            _get_operation_request(operation_id),
            _apis.OperationService.Stub,
            _apis.OperationService.GetOperation,
            ExportToS3Operation,
            settings,
            (self._driver,),
        )

    def export_to_s3(self, settings):
        return self._driver(
            _export_to_s3_request_factory(settings),
            ydb_export_v1_pb2_grpc.ExportServiceStub,
            _ExportToS3,
            ExportToS3Operation,
            settings,
            (self._driver,),
        )

    def export_to_yt(self, settings):
        return self._driver(
            _export_to_yt_request_factory(settings),
            ydb_export_v1_pb2_grpc.ExportServiceStub,
            _ExportToYt,
            ExportToYTOperation,
            settings,
            (self._driver,),
        )

    def async_export_to_yt(self, settings):
        return self._driver.future(
            _export_to_yt_request_factory(settings),
            ydb_export_v1_pb2_grpc.ExportServiceStub,
            _ExportToYt,
            ExportToYTOperation,
            settings,
            (self._driver,),
        )



from google.protobuf import struct_pb2 as _struct_pb2
from protos import ydb_formats_pb2 as _ydb_formats_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DecimalType(_message.Message):
    __slots__ = ("precision", "scale")
    PRECISION_FIELD_NUMBER: _ClassVar[int]
    SCALE_FIELD_NUMBER: _ClassVar[int]
    precision: int
    scale: int
    def __init__(self, precision: _Optional[int] = ..., scale: _Optional[int] = ...) -> None: ...

class OptionalType(_message.Message):
    __slots__ = ("item",)
    ITEM_FIELD_NUMBER: _ClassVar[int]
    item: Type
    def __init__(self, item: _Optional[_Union[Type, _Mapping]] = ...) -> None: ...

class ListType(_message.Message):
    __slots__ = ("item",)
    ITEM_FIELD_NUMBER: _ClassVar[int]
    item: Type
    def __init__(self, item: _Optional[_Union[Type, _Mapping]] = ...) -> None: ...

class VariantType(_message.Message):
    __slots__ = ("tuple_items", "struct_items")
    TUPLE_ITEMS_FIELD_NUMBER: _ClassVar[int]
    STRUCT_ITEMS_FIELD_NUMBER: _ClassVar[int]
    tuple_items: TupleType
    struct_items: StructType
    def __init__(self, tuple_items: _Optional[_Union[TupleType, _Mapping]] = ..., struct_items: _Optional[_Union[StructType, _Mapping]] = ...) -> None: ...

class TupleType(_message.Message):
    __slots__ = ("elements",)
    ELEMENTS_FIELD_NUMBER: _ClassVar[int]
    elements: _containers.RepeatedCompositeFieldContainer[Type]
    def __init__(self, elements: _Optional[_Iterable[_Union[Type, _Mapping]]] = ...) -> None: ...

class StructMember(_message.Message):
    __slots__ = ("name", "type")
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    name: str
    type: Type
    def __init__(self, name: _Optional[str] = ..., type: _Optional[_Union[Type, _Mapping]] = ...) -> None: ...

class StructType(_message.Message):
    __slots__ = ("members",)
    MEMBERS_FIELD_NUMBER: _ClassVar[int]
    members: _containers.RepeatedCompositeFieldContainer[StructMember]
    def __init__(self, members: _Optional[_Iterable[_Union[StructMember, _Mapping]]] = ...) -> None: ...

class DictType(_message.Message):
    __slots__ = ("key", "payload")
    KEY_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    key: Type
    payload: Type
    def __init__(self, key: _Optional[_Union[Type, _Mapping]] = ..., payload: _Optional[_Union[Type, _Mapping]] = ...) -> None: ...

class TaggedType(_message.Message):
    __slots__ = ("tag", "type")
    TAG_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    tag: str
    type: Type
    def __init__(self, tag: _Optional[str] = ..., type: _Optional[_Union[Type, _Mapping]] = ...) -> None: ...

class PgType(_message.Message):
    __slots__ = ("type_name", "type_modifier", "oid", "typlen", "typmod")
    TYPE_NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_MODIFIER_FIELD_NUMBER: _ClassVar[int]
    OID_FIELD_NUMBER: _ClassVar[int]
    TYPLEN_FIELD_NUMBER: _ClassVar[int]
    TYPMOD_FIELD_NUMBER: _ClassVar[int]
    type_name: str
    type_modifier: str
    oid: int
    typlen: int
    typmod: int
    def __init__(self, type_name: _Optional[str] = ..., type_modifier: _Optional[str] = ..., oid: _Optional[int] = ..., typlen: _Optional[int] = ..., typmod: _Optional[int] = ...) -> None: ...

class Type(_message.Message):
    __slots__ = ("type_id", "decimal_type", "optional_type", "list_type", "tuple_type", "struct_type", "dict_type", "variant_type", "tagged_type", "void_type", "null_type", "empty_list_type", "empty_dict_type", "pg_type")
    class PrimitiveTypeId(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        PRIMITIVE_TYPE_ID_UNSPECIFIED: _ClassVar[Type.PrimitiveTypeId]
        BOOL: _ClassVar[Type.PrimitiveTypeId]
        INT8: _ClassVar[Type.PrimitiveTypeId]
        UINT8: _ClassVar[Type.PrimitiveTypeId]
        INT16: _ClassVar[Type.PrimitiveTypeId]
        UINT16: _ClassVar[Type.PrimitiveTypeId]
        INT32: _ClassVar[Type.PrimitiveTypeId]
        UINT32: _ClassVar[Type.PrimitiveTypeId]
        INT64: _ClassVar[Type.PrimitiveTypeId]
        UINT64: _ClassVar[Type.PrimitiveTypeId]
        FLOAT: _ClassVar[Type.PrimitiveTypeId]
        DOUBLE: _ClassVar[Type.PrimitiveTypeId]
        DATE: _ClassVar[Type.PrimitiveTypeId]
        DATETIME: _ClassVar[Type.PrimitiveTypeId]
        TIMESTAMP: _ClassVar[Type.PrimitiveTypeId]
        INTERVAL: _ClassVar[Type.PrimitiveTypeId]
        TZ_DATE: _ClassVar[Type.PrimitiveTypeId]
        TZ_DATETIME: _ClassVar[Type.PrimitiveTypeId]
        TZ_TIMESTAMP: _ClassVar[Type.PrimitiveTypeId]
        DATE32: _ClassVar[Type.PrimitiveTypeId]
        DATETIME64: _ClassVar[Type.PrimitiveTypeId]
        TIMESTAMP64: _ClassVar[Type.PrimitiveTypeId]
        INTERVAL64: _ClassVar[Type.PrimitiveTypeId]
        STRING: _ClassVar[Type.PrimitiveTypeId]
        UTF8: _ClassVar[Type.PrimitiveTypeId]
        YSON: _ClassVar[Type.PrimitiveTypeId]
        JSON: _ClassVar[Type.PrimitiveTypeId]
        UUID: _ClassVar[Type.PrimitiveTypeId]
        JSON_DOCUMENT: _ClassVar[Type.PrimitiveTypeId]
        DYNUMBER: _ClassVar[Type.PrimitiveTypeId]
    PRIMITIVE_TYPE_ID_UNSPECIFIED: Type.PrimitiveTypeId
    BOOL: Type.PrimitiveTypeId
    INT8: Type.PrimitiveTypeId
    UINT8: Type.PrimitiveTypeId
    INT16: Type.PrimitiveTypeId
    UINT16: Type.PrimitiveTypeId
    INT32: Type.PrimitiveTypeId
    UINT32: Type.PrimitiveTypeId
    INT64: Type.PrimitiveTypeId
    UINT64: Type.PrimitiveTypeId
    FLOAT: Type.PrimitiveTypeId
    DOUBLE: Type.PrimitiveTypeId
    DATE: Type.PrimitiveTypeId
    DATETIME: Type.PrimitiveTypeId
    TIMESTAMP: Type.PrimitiveTypeId
    INTERVAL: Type.PrimitiveTypeId
    TZ_DATE: Type.PrimitiveTypeId
    TZ_DATETIME: Type.PrimitiveTypeId
    TZ_TIMESTAMP: Type.PrimitiveTypeId
    DATE32: Type.PrimitiveTypeId
    DATETIME64: Type.PrimitiveTypeId
    TIMESTAMP64: Type.PrimitiveTypeId
    INTERVAL64: Type.PrimitiveTypeId
    STRING: Type.PrimitiveTypeId
    UTF8: Type.PrimitiveTypeId
    YSON: Type.PrimitiveTypeId
    JSON: Type.PrimitiveTypeId
    UUID: Type.PrimitiveTypeId
    JSON_DOCUMENT: Type.PrimitiveTypeId
    DYNUMBER: Type.PrimitiveTypeId
    TYPE_ID_FIELD_NUMBER: _ClassVar[int]
    DECIMAL_TYPE_FIELD_NUMBER: _ClassVar[int]
    OPTIONAL_TYPE_FIELD_NUMBER: _ClassVar[int]
    LIST_TYPE_FIELD_NUMBER: _ClassVar[int]
    TUPLE_TYPE_FIELD_NUMBER: _ClassVar[int]
    STRUCT_TYPE_FIELD_NUMBER: _ClassVar[int]
    DICT_TYPE_FIELD_NUMBER: _ClassVar[int]
    VARIANT_TYPE_FIELD_NUMBER: _ClassVar[int]
    TAGGED_TYPE_FIELD_NUMBER: _ClassVar[int]
    VOID_TYPE_FIELD_NUMBER: _ClassVar[int]
    NULL_TYPE_FIELD_NUMBER: _ClassVar[int]
    EMPTY_LIST_TYPE_FIELD_NUMBER: _ClassVar[int]
    EMPTY_DICT_TYPE_FIELD_NUMBER: _ClassVar[int]
    PG_TYPE_FIELD_NUMBER: _ClassVar[int]
    type_id: Type.PrimitiveTypeId
    decimal_type: DecimalType
    optional_type: OptionalType
    list_type: ListType
    tuple_type: TupleType
    struct_type: StructType
    dict_type: DictType
    variant_type: VariantType
    tagged_type: TaggedType
    void_type: _struct_pb2.NullValue
    null_type: _struct_pb2.NullValue
    empty_list_type: _struct_pb2.NullValue
    empty_dict_type: _struct_pb2.NullValue
    pg_type: PgType
    def __init__(self, type_id: _Optional[_Union[Type.PrimitiveTypeId, str]] = ..., decimal_type: _Optional[_Union[DecimalType, _Mapping]] = ..., optional_type: _Optional[_Union[OptionalType, _Mapping]] = ..., list_type: _Optional[_Union[ListType, _Mapping]] = ..., tuple_type: _Optional[_Union[TupleType, _Mapping]] = ..., struct_type: _Optional[_Union[StructType, _Mapping]] = ..., dict_type: _Optional[_Union[DictType, _Mapping]] = ..., variant_type: _Optional[_Union[VariantType, _Mapping]] = ..., tagged_type: _Optional[_Union[TaggedType, _Mapping]] = ..., void_type: _Optional[_Union[_struct_pb2.NullValue, str]] = ..., null_type: _Optional[_Union[_struct_pb2.NullValue, str]] = ..., empty_list_type: _Optional[_Union[_struct_pb2.NullValue, str]] = ..., empty_dict_type: _Optional[_Union[_struct_pb2.NullValue, str]] = ..., pg_type: _Optional[_Union[PgType, _Mapping]] = ...) -> None: ...

class ValuePair(_message.Message):
    __slots__ = ("key", "payload")
    KEY_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    key: Value
    payload: Value
    def __init__(self, key: _Optional[_Union[Value, _Mapping]] = ..., payload: _Optional[_Union[Value, _Mapping]] = ...) -> None: ...

class Value(_message.Message):
    __slots__ = ("bool_value", "int32_value", "uint32_value", "int64_value", "uint64_value", "float_value", "double_value", "bytes_value", "text_value", "null_flag_value", "nested_value", "low_128", "items", "pairs", "variant_index", "high_128")
    BOOL_VALUE_FIELD_NUMBER: _ClassVar[int]
    INT32_VALUE_FIELD_NUMBER: _ClassVar[int]
    UINT32_VALUE_FIELD_NUMBER: _ClassVar[int]
    INT64_VALUE_FIELD_NUMBER: _ClassVar[int]
    UINT64_VALUE_FIELD_NUMBER: _ClassVar[int]
    FLOAT_VALUE_FIELD_NUMBER: _ClassVar[int]
    DOUBLE_VALUE_FIELD_NUMBER: _ClassVar[int]
    BYTES_VALUE_FIELD_NUMBER: _ClassVar[int]
    TEXT_VALUE_FIELD_NUMBER: _ClassVar[int]
    NULL_FLAG_VALUE_FIELD_NUMBER: _ClassVar[int]
    NESTED_VALUE_FIELD_NUMBER: _ClassVar[int]
    LOW_128_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    PAIRS_FIELD_NUMBER: _ClassVar[int]
    VARIANT_INDEX_FIELD_NUMBER: _ClassVar[int]
    HIGH_128_FIELD_NUMBER: _ClassVar[int]
    bool_value: bool
    int32_value: int
    uint32_value: int
    int64_value: int
    uint64_value: int
    float_value: float
    double_value: float
    bytes_value: bytes
    text_value: str
    null_flag_value: _struct_pb2.NullValue
    nested_value: Value
    low_128: int
    items: _containers.RepeatedCompositeFieldContainer[Value]
    pairs: _containers.RepeatedCompositeFieldContainer[ValuePair]
    variant_index: int
    high_128: int
    def __init__(self, bool_value: bool = ..., int32_value: _Optional[int] = ..., uint32_value: _Optional[int] = ..., int64_value: _Optional[int] = ..., uint64_value: _Optional[int] = ..., float_value: _Optional[float] = ..., double_value: _Optional[float] = ..., bytes_value: _Optional[bytes] = ..., text_value: _Optional[str] = ..., null_flag_value: _Optional[_Union[_struct_pb2.NullValue, str]] = ..., nested_value: _Optional[_Union[Value, _Mapping]] = ..., low_128: _Optional[int] = ..., items: _Optional[_Iterable[_Union[Value, _Mapping]]] = ..., pairs: _Optional[_Iterable[_Union[ValuePair, _Mapping]]] = ..., variant_index: _Optional[int] = ..., high_128: _Optional[int] = ...) -> None: ...

class TypedValue(_message.Message):
    __slots__ = ("type", "value")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    type: Type
    value: Value
    def __init__(self, type: _Optional[_Union[Type, _Mapping]] = ..., value: _Optional[_Union[Value, _Mapping]] = ...) -> None: ...

class Column(_message.Message):
    __slots__ = ("name", "type")
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    name: str
    type: Type
    def __init__(self, name: _Optional[str] = ..., type: _Optional[_Union[Type, _Mapping]] = ...) -> None: ...

class ResultSet(_message.Message):
    __slots__ = ("columns", "rows", "truncated", "format", "arrow_format_meta", "data")
    class Format(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        FORMAT_UNSPECIFIED: _ClassVar[ResultSet.Format]
        FORMAT_VALUE: _ClassVar[ResultSet.Format]
        FORMAT_ARROW: _ClassVar[ResultSet.Format]
    FORMAT_UNSPECIFIED: ResultSet.Format
    FORMAT_VALUE: ResultSet.Format
    FORMAT_ARROW: ResultSet.Format
    COLUMNS_FIELD_NUMBER: _ClassVar[int]
    ROWS_FIELD_NUMBER: _ClassVar[int]
    TRUNCATED_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    ARROW_FORMAT_META_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    columns: _containers.RepeatedCompositeFieldContainer[Column]
    rows: _containers.RepeatedCompositeFieldContainer[Value]
    truncated: bool
    format: ResultSet.Format
    arrow_format_meta: _ydb_formats_pb2.ArrowFormatMeta
    data: bytes
    def __init__(self, columns: _Optional[_Iterable[_Union[Column, _Mapping]]] = ..., rows: _Optional[_Iterable[_Union[Value, _Mapping]]] = ..., truncated: bool = ..., format: _Optional[_Union[ResultSet.Format, str]] = ..., arrow_format_meta: _Optional[_Union[_ydb_formats_pb2.ArrowFormatMeta, _Mapping]] = ..., data: _Optional[bytes] = ...) -> None: ...
